**Example 1: 批量删除规则引擎规则**



Input: 

```
tccli teo DeleteRules --cli-unfold-argument  \
    --RuleIds rule-66tjz30m rule-bx3zke8q \
    --ZoneId zone-26r78x31ny86
```

Output: 
```
{
    "Response": {
        "RequestId": "ace05891-744c-40f8-94de-4e1c08d954c2"
    }
}
```

